@@ -33,7 +33,7 @@ ac_table = {
             '--download-proxy',
             '--index-data-url',
             '--port-expose',
-            '--parallel',
+            '--replicas',
             '--unblock-query-flow',
         ],
         'hello multimodal': [
@@ -58,6 +58,7 @@ ac_table = {
             '--workspace-id',
             '--static-routing-table',
             '--routing-table',
+            '--dynamic-routing',
             '--zmq-identity',
             '--port-ctrl',
             '--ctrl-with-ipc',
@@ -86,8 +87,7 @@ ac_table = {
             '--grpc-data-requests',
             '--runs-in-docker',
             '--dump-path',
-            '--k8s-connection-pool',
-            '--k8s-no-connection-pool',
+            '--k8s-disable-connection-pool',
             '--entrypoint',
             '--docker-kwargs',
             '--pull-latest',
@@ -105,9 +105,13 @@ ac_table = {
             '--timeout-ready',
             '--env',
             '--expose-public',
+            '--shard-id',
             '--pea-id',
             '--pea-role',
             '--noblock-on-start',
+            '--shards',
+            '--parallel',
+            '--replicas',
             '--install-requirements',
             '--force',
         ],
@@ -122,6 +126,7 @@ ac_table = {
             '--workspace-id',
             '--static-routing-table',
             '--routing-table',
+            '--dynamic-routing',
             '--uses',
             '--env',
             '--inspect',
@@ -140,6 +145,7 @@ ac_table = {
             '--workspace-id',
             '--static-routing-table',
             '--routing-table',
+            '--dynamic-routing',
             '--zmq-identity',
             '--port-ctrl',
             '--ctrl-with-ipc',
@@ -168,10 +174,8 @@ ac_table = {
             '--grpc-data-requests',
             '--runs-in-docker',
             '--dump-path',
-            '--k8s-connection-pool',
-            '--k8s-no-connection-pool',
+            '--k8s-disable-connection-pool',
             '--prefetch',
-            '--prefetch-on-recv',
             '--title',
             '--description',
             '--cors',
@@ -194,14 +198,17 @@ ac_table = {
             '--timeout-ready',
             '--env',
             '--expose-public',
+            '--shard-id',
             '--pea-id',
             '--pea-role',
             '--noblock-on-start',
+            '--shards',
+            '--parallel',
+            '--replicas',
             '--k8s-uses-init',
             '--k8s-mount-path',
             '--k8s-init-container-command',
             '--k8s-custom-resource-dir',
-            '--dynamic-routing',
         ],
         'hub new': [
             '--help',
@@ -238,6 +245,7 @@ ac_table = {
             '--workspace-id',
             '--static-routing-table',
             '--routing-table',
+            '--dynamic-routing',
             '--zmq-identity',
             '--port-ctrl',
             '--ctrl-with-ipc',
@@ -266,8 +274,7 @@ ac_table = {
             '--grpc-data-requests',
             '--runs-in-docker',
             '--dump-path',
-            '--k8s-connection-pool',
-            '--k8s-no-connection-pool',
+            '--k8s-disable-connection-pool',
             '--entrypoint',
             '--docker-kwargs',
             '--pull-latest',
@@ -285,9 +292,13 @@ ac_table = {
             '--timeout-ready',
             '--env',
             '--expose-public',
+            '--shard-id',
             '--pea-id',
             '--pea-role',
             '--noblock-on-start',
+            '--shards',
+            '--parallel',
+            '--replicas',
             '--install-requirements',
             '--force',
         ],
@@ -303,6 +314,7 @@ ac_table = {
             '--workspace-id',
             '--static-routing-table',
             '--routing-table',
+            '--dynamic-routing',
             '--zmq-identity',
             '--port-ctrl',
             '--ctrl-with-ipc',
@@ -331,8 +343,7 @@ ac_table = {
             '--grpc-data-requests',
             '--runs-in-docker',
             '--dump-path',
-            '--k8s-connection-pool',
-            '--k8s-no-connection-pool',
+            '--k8s-disable-connection-pool',
             '--entrypoint',
             '--docker-kwargs',
             '--pull-latest',
@@ -350,16 +361,17 @@ ac_table = {
             '--timeout-ready',
             '--env',
             '--expose-public',
+            '--shard-id',
             '--pea-id',
             '--pea-role',
             '--noblock-on-start',
+            '--shards',
+            '--parallel',
+            '--replicas',
             '--install-requirements',
             '--force',
             '--uses-before',
             '--uses-after',
-            '--parallel',
-            '--shards',
-            '--replicas',
             '--polling',
             '--scheduling',
             '--external',
