@@ -130,8 +130,8 @@ class PartialFlowStore(PartialStore):
                         + list(GATEWAY_RUNTIME_DICT.values())
                     ):
                         pod.args.runs_in_docker = False
-                        for replica_args in pod.replicas_args:
-                            replica_args.runs_in_docker = False
+                        for shards_args in pod.shards_args:
+                            shards_args.runs_in_docker = False
                         if port_mapping:
                             # Ports for Head & Tail Peas in a CompoundPod set here.
                             # This is specifically needed as `save_config` doesn't save `port_out` for a HeadPea
@@ -140,27 +140,30 @@ class PartialFlowStore(PartialStore):
                             for pea_args in [pod.head_args, pod.tail_args]:
                                 if pea_args.name in port_mapping.pea_names:
                                     for port_name in Ports.__fields__:
-                                        if hasattr(pea_args, port_name):
-                                            setattr(
-                                                pea_args,
-                                                port_name,
-                                                getattr(
-                                                    port_mapping[pea_args.name].ports,
-                                                    port_name,
-                                                    random_port(),
-                                                ),
-                                            )
-                            # Update replica_args according to updated head & tail args
-                            pod.assign_replicas()
+                                        self._set_pea_ports(
+                                            pea_args, port_mapping, port_name
+                                        )
+                            # Update shard_args according to updated head & tail args
+                            pod.assign_shards()
                 else:
+                    if port_mapping and (
+                        hasattr(pod.args, 'replicas') and pod.args.replicas > 1
+                    ):
+                        for pea_args in [pod.peas_args['head'], pod.peas_args['tail']]:
+                            if pea_args.name in port_mapping.pea_names:
+                                for port_name in Ports.__fields__:
+                                    self._set_pea_ports(
+                                        pea_args, port_mapping, port_name
+                                    )
+                        pod.update_worker_pea_args()
+
                     # avoid setting runs_in_docker for Pods with parallel > 1 and using `ZEDRuntime`
                     # else, replica-peas would try connecting to head/tail-pea via __docker_host__
-                    if (
-                        runtime_cls in ['ZEDRuntime', 'GRPCDataRuntime']
-                        and pod.args.parallel > 1
+                    if runtime_cls in ['ZEDRuntime', 'GRPCDataRuntime'] and (
+                        hasattr(pod.args, 'replicas') and pod.args.replicas > 1
                     ):
                         pod.args.runs_in_docker = False
-                        pod.update_pea_args()
+                        pod.update_worker_pea_args()
 
             self.object = self.object.__enter__()
         except Exception as e:
@@ -180,6 +183,18 @@ class PartialFlowStore(PartialStore):
             self._logger.success(f'Flow is created')
             return self.item
 
+    def _set_pea_ports(self, pea_args, port_mapping, port_name):
+        if hasattr(pea_args, port_name):
+            setattr(
+                pea_args,
+                port_name,
+                getattr(
+                    port_mapping[pea_args.name].ports,
+                    port_name,
+                    random_port(),
+                ),
+            )
+
     def update(
         self,
         kind: UpdateOperation,
@@ -200,7 +215,7 @@ class PartialFlowStore(PartialStore):
             if kind == UpdateOperation.ROLLING_UPDATE:
                 self.object.rolling_update(pod_name=pod_name, dump_path=dump_path)
             else:
-                self._logger.error(f'unsupoorted kind: {kind}, no changes done')
+                self._logger.error(f'unsupported kind: {kind}, no changes done')
                 return self.item
         except Exception as e:
             self._logger.error(f'{e!r}')
